@@ -35,7 +35,7 @@ typedef enum {
     GPDS_TOUCHPAD_SCROLLING_DISTANCE,
     GPDS_TOUCHPAD_EDGE_SCROLLING,
     GPDS_TOUCHPAD_TWO_FINGER_SCROLLING,
-    GPDS_TOUCHPAD_SYNAPTICS_PROP_SPEED,
+    GPDS_TOUCHPAD_MOVE_SPEED,
     GPDS_TOUCHPAD_EDGE_MOTION_PRESSURE,
     GPDS_TOUCHPAD_EDGE_MOTION_SPEED,
     GPDS_TOUCHPAD_BUTTON_SCROLLING,
